Internal library crate for the oy binary.
oy
The supported automation surface is the oy command-line interface. Rust module paths and exported items beyond run and err_line are intentionally unstable while the binary is still evolving.
run
err_line